@@ -154,6 +154,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "animation",
     "annotation",
     "annotation-xml",
+    "anonymous",
     "apply",
     "approx",
     "arabic-form",
@@ -784,6 +785,8 @@ pub static ATOMS: &'static [&'static str] = &[
     "nest",
     "nextid",
     "no message",
+    "no-referrer",
+    "no-referrer-when-downgrade",
     "nobr",
     "noembed",
     "nohref",
@@ -908,6 +911,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "orient",
     "orientation",
     "origin",
+    "origin-when-cross-origin",
     "other",
     "otherwise",
     "outerproduct",
@@ -1191,10 +1195,12 @@ pub static ATOMS: &'static [&'static str] = &[
     "unicode-range",
     "union",
     "units-per-em",
+    "unsafe-url",
     "unselectable",
     "uplimit",
     "url",
     "use",
+    "use-credentials",
     "usemap",
     "UTF-8",
     "valign",
